thorn.django.rest_framework.serializers — Thorn 1.3.0 documentation

# thorn.django.rest_framework.serializers

- thorn.django.rest_framework.serializers

## thorn.django.rest_framework.serializers

Rest framework serializers.

class `thorn.django.rest_framework.serializers.` `SubscriberSerializer`(instance=None, data=<class rest_framework.fields.empty>, **kwargs)
  class `Meta`
    `fields` = (u'event', u'url', u'content_type', u'user', u'id', u'created_at', u'updated_at', u'subscription', u'hmac_secret', u'hmac_digest')
    `model`

      alias of `Subscriber`

    `read_only_fields` = (u'id', u'created_at', u'updated_at', u'subscription')